Crate assertr

Crate assertr 

Modules

actual
assertions
cmp
condition
details
failure
mode
prelude
tracking
util

Macros

assert_that
The main entrypoint in an assertion context, usable with both owned and borrowed values.

Structs

AssertThat
AssertThat is the core structure used for assertions. It allows developers to perform assertions on actual values in a fluent and expressive manner, supporting detailed messages as well as different modes of operation, such as panic or capture modes.
Differences
EqContext
PanicValue
Type

Enums

Eq

Traits

AssertingThat
AssertingThatRef
AssertrPartialEq

Functions

any
assert_thatDeprecated
Entrypoint for asserting on owned values.
assert_that_panic_by
assert_that_panic_by_async
assert_that_refDeprecated
Entrypoint for asserting on borrowed values.
assert_that_type
eq